@@ -362,8 +362,8 @@ add_underline (PangoRenderer    *renderer,
   int underline_thickness = pango_font_metrics_get_underline_thickness (metrics);
   int underline_position = pango_font_metrics_get_underline_position (metrics);
 
-  new_rect.x = base_x + ink_rect->x;
-  new_rect.width = ink_rect->width;
+  new_rect.x = base_x + MIN (ink_rect->x, logical_rect->x);
+  new_rect.width = MAX (ink_rect->width, logical_rect->width);
   new_rect.height = underline_thickness;
   new_rect.y = base_y;
 
@@ -575,7 +575,7 @@ pango_renderer_draw_layout_line (PangoRenderer   *renderer,
 {
   int x_off = 0;
   int glyph_string_width;
-  LineState state;
+  LineState state = { 0, };
   GSList *l;
   gboolean got_overall = FALSE;
   PangoRectangle overall_rect;
